@@ -41,6 +41,7 @@ static gchar *contributors[] = {
 	"Stephen Browne",
 	"Marcus Brubaker",
 	"Christian Bucher",
+	"Ross Burton",
 	"Dave Camp",
 	"Didier Carlier",
 	"Anders Carlsson",
@@ -251,6 +252,7 @@ static gchar *contributors[] = {
 	"Jens Christian Restemeier",
 	"Patrick Reynolds",
 	"Robert Richardson",
+	"Kristian Rietveld",
 	"Alex Roberts",
 	"Michel Roelofs",
 	"Ueli Rutishauser",
@@ -282,6 +284,7 @@ static gchar *contributors[] = {
 	"John Slee",
 	"Garrett Smith",
 	"Suzanna Smith",
+	"Andrew Sobala",
 	/* not really a person name :) translate its meaning */
 	N_("The Squeaky Rubber Gnome"),
 	"Maciej Stachowiak",
